pub struct AsyncSignal { /* private fields */ }Implementations
Sourceimpl AsyncSignal
Handle signals asynchronously.
impl AsyncSignal
Handle signals asynchronously.
Receiving the same signal with multiple Signal instances is not supported.
Attempting to receive a signal which is blocked will result in an error.