pub unsafe fn shutdown_executor_unchecked()Expand description
Removes all pending tasks from the executor and returns control to the caller.
This will cause epox::run() to return as soon as control is returned
to the executor.
If you don’t need to return a value from the task that shuts down the
executor, you should probably use shutdown().
Safety
Callers should not call .await after calling this function. This
will return control to the executor which will not wake previously
registered tasks.